@@ -471,7 +471,10 @@ def addhubuser(hubname,
 			print "creating homedir: " + homeDir
 
 			# set ownership
-			os.chown(homeDir, uidNumber, gidNumber)
+			if not skipCreateGroup:
+				os.chown(homeDir, uidNumber, gidNumber)
+			else:
+				os.chown(homeDir, uidNumber, -1)
 
 			# change permissions user full, noone else has anything
 			rc, procStdOut, procStdErr = hubzero.utilities.misc.exShellCommand(["chmod", '700', homeDir])
